from django.urls import path, include
from . import views
from django.http import HttpResponse


# 添加一个简单的index视图函数
# def index(request):
#     return HttpResponse("Welcome to TikTok Videos Analysis API")


urlpatterns = [
    # path('', index, name='index'),
    # # TikTok API路由 - 旧路径保持不变以保证兼容性
    # path('tiktok/user-videos/', views.get_tiktok_user_videos, name='get-tiktok-user-videos'),
    # path('tiktok/fetch_videos/', views.fetch_tiktok_videos, name='fetch_tiktok_videos'),
    # path('tiktok/delete_user/', views.delete_tiktok_user, name='delete_tiktok_user'),


    # 搜索公有达人
    path('creators/search/', views.search_creators, name='search_creators'),
        # 搜索私有达人
    path('private/creators/search/', views.search_private_creators, name='search_private_creators'),


    # 新的API路由结构 - 只保留TikTok API
    # path('api/tiktok/', include('app.api.tiktok.urls')),  # TikTok API

    # 添加Creator相关API
    path('creators/filter/', views.filter_creators, name='filter_creators'),
    path('creators/add/', views.add_creator, name='add_creator'),
    path('creators/<int:creator_id>/', views.get_creator_detail, name='get_creator_detail'),
    path('creators/update_detail/', views.update_creator_detail, name='update_creator_detail'),
    path('creators/<int:creator_id>/campaigns/', views.get_creator_brand_campaigns, name='get_creator_brand_campaigns'),

    # 添加Campaign相关API
    path('campaigns/', views.get_campaigns, name='get_campaigns'),
    path('campaigns/add/', views.add_to_campaign, name='add_to_campaign'),
    # 新增品牌合作活动列表API
    path('brand/campaigns/', views.get_brand_campaigns, name='get_brand_campaigns'),

    # 新增的指标相关API
    path('creators/<int:creator_id>/metrics/', views.get_creator_metrics, name='get_creator_metrics'),
    # 获取创作者的所有指标数据
    path('creators/metrics/update/', views.update_creator_metrics, name='update_creator_metrics'),  # 更新创作者的指标数据

    # 添加粉丝统计和趋势数据相关的路由
    path('creator/<int:creator_id>/followers/', views.get_creator_followers_metrics, name='get_creator_followers'),
    path('creator/followers/', views.get_creator_followers_metrics, name='get_creator_followers_query'),

    # 获取创作者趋势数据
    path('creator/<int:creator_id>/trends/', views.get_creator_trends, name='get_creator_trends'),
    path('creator/trends/', views.get_creator_trends, name='get_creator_trends_query'),

    # 更新创作者粉丝统计数据
    path('creator/followers/update/', views.update_creator_followers, name='update_creator_followers'),

    # 更新创作者趋势数据
    path('creator/trend/update/', views.update_creator_trend, name='update_creator_trend'),

    # 添加创作者视频相关的路由
    path('creator/<int:creator_id>/videos/', views.get_creator_videos, name='get_creator_videos'),
    path('creator/videos/', views.get_creator_videos, name='get_creator_videos_query'),

    # 添加创作者视频
    path('creator/video/add/', views.add_creator_video, name='add_creator_video'),

    # 公有达人和私有达人API
    path('public/creators/', views.get_public_creators, name='get_public_creators'),
    path('public/creators/filter/', views.filter_public_creators, name='filter_public_creators'),
    path('public/creators/add/', views.add_to_public_pool, name='add_to_public_pool'),
    path('public/creators/remove/', views.remove_from_public_pool, name='remove_from_public_pool'),

    # 私有达人库
    path('private/pools/', views.get_private_pools, name='get_private_pools'),
    path('private/pools/create/', views.create_private_pool, name='create_private_pool'),
    path('private/pools/creators/<int:pool_id>/', views.get_private_pool_creators, name='get_private_pool_creators'),
    path('private/pools/creators/', views.get_private_pool_creators, name='get_private_pool_creators_no_id'),
    path('private/pools/creators/add/', views.add_creator_to_private_pool, name='add_creator_to_private_pool'),
    path('private/pools/creators/update/', views.update_creator_in_private_pool, name='update_creator_in_private_pool'),
    path('private/pools/creators/remove/', views.remove_creator_from_private_pool, name='remove_creator_from_private_pool'),
    path('private/pools/creators/filter/', views.filter_private_pool_creators, name='filter_private_pool_creators'),
]
